==> seqan2_2.3.2+dfsg2.orig.tar.xz: seqan-seqan-v2.3.2/tests/reduced_aminoacid/test_reduced_aminoacid.cpp <==
// ==========================================================================
//                 SeqAn - The Library for Sequence Analysis
// ==========================================================================
// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of Knut Reinert or the FU Berlin nor the names of
//       its contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL KNUT REINERT OR THE FU BERLIN BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
// DAMAGE.
//
// ==========================================================================
// Author: Hannes Hauswedell <hannes.hauswedell@fu-berlin.de>
// ==========================================================================
// Tests for reduced_aminoacid
// ==========================================================================

#include <seqan/basic.h>
#include <seqan/sequence.h>

#include "test_reduced_aminoacid.h"

SEQAN_BEGIN_TESTSUITE(test_reduced_aminoacid)
{
//     SEQAN_CALL_TEST(test_reduced_aminoacid_cluster_red);
    SEQAN_CALL_TEST(test_reduced_aminoacid_murphy10);
    SEQAN_CALL_TEST(test_reduced_aminoacid_murphy10_moditerators);
    SEQAN_CALL_TEST(test_reduced_aminoacid_murphy10_modview_fmindex);
}
SEQAN_END_TESTSUITE

==> seqan2_2.4.0+dfsg.orig.tar.xz: seqan-seqan-v2.4.0/tests/reduced_aminoacid/test_reduced_aminoacid.cpp <==
// ==========================================================================
//                 SeqAn - The Library for Sequence Analysis
// ==========================================================================
// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of Knut Reinert or the FU Berlin nor the names of
//       its contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL KNUT REINERT OR THE FU BERLIN BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
// DAMAGE.
//
// ==========================================================================
// Author: Hannes Hauswedell <hannes.hauswedell@fu-berlin.de>
// ==========================================================================
// Tests for reduced_aminoacid
// ==========================================================================

#include <seqan/basic.h>
#include <seqan/sequence.h>

#include "test_reduced_aminoacid.h"

SEQAN_BEGIN_TESTSUITE(test_reduced_aminoacid)
{
//     SEQAN_CALL_TEST(test_reduced_aminoacid_cluster_red);
    SEQAN_CALL_TEST(test_reduced_aminoacid_buchfink11);
    SEQAN_CALL_TEST(test_reduced_aminoacid_cannata10);
    SEQAN_CALL_TEST(test_reduced_aminoacid_li10);
    SEQAN_CALL_TEST(test_reduced_aminoacid_solis10);
    SEQAN_CALL_TEST(test_reduced_aminoacid_murphy5);
    SEQAN_CALL_TEST(test_reduced_aminoacid_murphy10);
    SEQAN_CALL_TEST(test_reduced_aminoacid_murphy10_moditerators);
    SEQAN_CALL_TEST(test_reduced_aminoacid_murphy10_modview_fmindex);
}
SEQAN_END_TESTSUITE
